@@ -262,6 +262,7 @@ readonly OUTPUT_FILE_OVS="${WORKPATH}network.out"
 readonly OUTPUT_FILE_ISW="${WORKPATH}installed_sw.out"
 readonly OUTPUT_FILE_TC="${WORKPATH}network.out"
 readonly OUTPUT_FILE_VMCMD="${WORKPATH}zvm_runtime.out"
+readonly OUTPUT_FILE_UDEVDB="${WORKPATH}udevdb.out"
 # Base file names for different output files - no extension !
 readonly OUTPUT_FILE_KUBERNETES="${WORKPATH}kubernetes"
 readonly OUTPUT_FILE_OSAOAT="${WORKPATH}network"
@@ -400,6 +401,7 @@ CONFIGFILES="\
   /etc/hosts*\
   /etc/iscsi\
   /etc/inittab\
+  /etc/kdump\
   /etc/libvirt\
   /etc/logrotate.d\
   /etc/lvm\
@@ -439,6 +441,7 @@ CONFIGFILES="\
   /run/modules-load.d/*.conf\
   /run/udev/chreiplzfcpmp-ipl-volume-id\
   /run/udev/rules.d\
+  /run/zdev_id.env\
   "
 
 ########################################
@@ -555,6 +558,7 @@ CMDS="${CMDS}\
    >> '${OUTPUT_FILE_JOURNALCTL}'\
   :lsof >> '${OUTPUT_FILE_LSOF}'\
   :rpm -qa | sort >> '${OUTPUT_FILE_ISW}'\
+  :udevadm info --export-db >> '${OUTPUT_FILE_UDEVDB}'\
   "
 
 ########################################
@@ -833,6 +837,7 @@ collect_sysfs() {
 		    -x '*/page_idle/bitmap*' \
 		    -x '*/tracing/per_cpu/*' \
 		    -x '*/tracing/free_buffer' \
+		    -x '*/devices/css[0-9]*/[0-9]*.*.*/[0-9]*.*.*/host[0-9]*/rport-[0-9]*:*-*/target[0-9]*:*:*/[0-9]*:*:*:*/block/sd*/mq/0/cpu[0-9]*' \
 		    --ignore-failed-read -J 1 -T 5 2>>${OUTPUT_FILE_SYSFS}.err
 		rc=$?
 	else
@@ -860,6 +865,7 @@ collect_sysfs() {
 		    -a -not \( -path '*page_idle*' -a -name 'bitmap*' \) \
 		    -a -not -path '*tracing/per_cpu*' \
 		    -a -not -path '*/tracing/free_buffer' \
+		    -a -not -path '*/devices/css[0-9]*/[0-9]*.*.*/[0-9]*.*.*/host[0-9]*/rport-[0-9]*:*-*/target[0-9]*:*:*/[0-9]*:*:*:*/block/sd*/mq/0/cpu[0-9]*' \
 		    2>/dev/null | while IFS= read -r file_name; do
 			echo " ${file_name}"
 			if ! dd if="${file_name}" status=noxfer iflag=nonblock \
@@ -904,7 +910,8 @@ collect_osaoat() {
 	local network_device
 
 	network_devices=$(lsqeth 2>/dev/null | grep "Device name" \
-		     | sed 's/D.*:[[:space:]]*\([^[:space:]]*\)[[:space:]]\+/\1/g')
+		     | sed 's/D.*:[[:space:]]*\([^[:space:]]*\)[[:space:]]\+/\1/g' \
+		     | sed 's/[()]//g' )
 	if type qethqoat >/dev/null; then
 		if test -n "${network_devices}"; then
 			pr_collect_output "osa oat"
@@ -954,6 +961,8 @@ collect_ethtool() {
 					"${OUTPUT_FILE_ETHTOOL}"
 				call_run_command "ethtool -T ${network_device}" \
 					"${OUTPUT_FILE_ETHTOOL}"
+				call_run_command "ethtool --module-info ${network_device}" \
+					"${OUTPUT_FILE_ETHTOOL}"
 			done
 		else
 			pr_skip "ethtool: no devices"
@@ -1389,7 +1398,7 @@ pr_log_stdout() {
 pr_syslog_stdout() {
 	echo "$@" >&8
 	echo
-	echo "$(date +%H:%M:%S.%N) - $@"
+	echo "$(date +%H:%M:%S.%N) - " "$@"
 	logger -t "${SCRIPTNAME}" "$@"
 }
 
@@ -1402,13 +1411,13 @@ pr_collect_output() {
 ########################################
 # print "Collecting ..." like fs
 pr_collect() {
-	pr_syslog_stdout ${step_num} "Collecting" $@
+	pr_syslog_stdout ${step_num} "Collecting" "$@"
 }
 
 ########################################
 # print "Skipping ..." info with reason
 pr_skip() {
-	pr_syslog_stdout ${step_num} "Skip" $@
+	pr_syslog_stdout ${step_num} "Skip" "$@"
 }
 
 ###############################################################################
